@@ -1,10 +1,12 @@
 #[macro_use] extern crate anyhow;
 #[macro_use] extern crate lazy_static;
+#[macro_use] extern crate combine;
 #[macro_use] extern crate netidx_core;
 #[macro_use] extern crate serde_derive;
 
 pub mod glob;
 pub mod publisher;
+pub mod value_parser;
 pub mod value;
 pub mod resolver;
 
